@@ -321,20 +321,14 @@ class FutureWithTask(asyncio.Future, RunnableInterface):
     """Future实例可以被多个协程await，本类实现Future和Task的桥接
     """
 
-    def __init__(self, func, name=None):
+    def __init__(self, func):
 
         super().__init__()
 
-        self._name = Utils.uuid1() if name is None else name
         self._task = None
         self._callable = func
         self._build_time = Utils.loop_time()
 
-    @property
-    def name(self):
-
-        return self._name
-
     @property
     def task(self):
 
