@@ -168,7 +168,7 @@ class Launcher(RunnableInterface):
     """
 
     def __init__(self,
-                 log_level=r'info', log_handler=None, log_file_path=None, log_file_name=DEFAULT_LOG_FILE_NAME,
+                 log_level=r'INFO', log_handler=None, log_file_path=None, log_file_name=DEFAULT_LOG_FILE_NAME,
                  log_file_rotation=DEFAULT_LOG_FILE_ROTATOR, log_file_retention=0xff, log_extra=None, log_enqueue=False,
                  daemon=None, debug=False
                  ):
