@@ -2,8 +2,9 @@
 
 __author__ = r'wsb310@gmail.com'
 
-from hagworm.extend.event import EventDispatcher
-from hagworm.extend.asyncio.base import Utils, AsyncCirculatorForSecond, FuncWrapper, FutureWithTimeout
+from .base import Utils, AsyncCirculatorForSecond, FuncWrapper, FutureWithTimeout
+
+from ..event import EventDispatcher
 
 
 class EventDispatcher(EventDispatcher):
