@@ -8,14 +8,14 @@ import aiohttp
 
 from contextlib import contextmanager
 
-from ..struct import Enum
+from ..struct import IntEnum
 from ..interface import ContextManager
 
 from .base import Utils, AsyncCirculatorForSecond
 from .buffer import FileBuffer
 
 
-class STATE(Enum):
+class STATE(IntEnum):
 
     PENDING = 0x00
     FETCHING = 0x01
@@ -26,9 +26,11 @@ class STATE(Enum):
 DEFAULT_TIMEOUT = aiohttp.client.ClientTimeout(total=60, connect=10, sock_read=60, sock_connect=10)
 DOWNLOAD_TIMEOUT = aiohttp.client.ClientTimeout(total=600, connect=10, sock_read=600, sock_connect=10)
 
-CACERT_FILE = os.path.join(
-    os.path.split(os.path.abspath(__file__))[0],
-    r'../../static/cacert.pem'
+DEFAULT_SSL_CONTEXT = ssl.create_default_context(
+    cafile=os.path.join(
+        os.path.split(os.path.abspath(__file__))[0],
+        r'../../static/cacert.pem'
+    )
 )
 
 
@@ -71,6 +73,33 @@ def _json_decoder(val, **kwargs):
         Utils.log.warning(f'http client json decode error: {err} => {val}')
 
 
+def create_timeout(total=None, connect=None, sock_read=None, sock_connect=None) -> aiohttp.client.ClientTimeout:
+    """生成超时配置对象
+
+    Args:
+        total: 总超时时间
+        connect: 从连接池中等待获取连接的超时时间
+        sock_read: Socket数据接收的超时时间
+        sock_connect: Socket连接的超时时间
+
+    """
+
+    return aiohttp.client.ClientTimeout(
+        total=total, connect=connect,
+        sock_read=sock_read, sock_connect=sock_connect
+    )
+
+
+def create_ssl_context(cafile, *, certfile=None, keyfile=..., password=...) -> ssl.SSLContext:
+
+    ssl_context = ssl.create_default_context(cafile=cafile)
+
+    if certfile is not None:
+        ssl_context.load_cert_chain(certfile, keyfile, password)
+
+    return ssl_context
+
+
 class Result(dict):
 
     def __init__(self, status, headers, cookies, body):
@@ -106,16 +135,13 @@ class _HTTPClient:
     """HTTP客户端基类
     """
 
-    def __init__(self, retry_count=5, timeout=None, **kwargs):
-
-        global DEFAULT_TIMEOUT
-
-        self._ssl_context = self._create_ssl_context()
+    def __init__(self, retry_count=5, timeout=DEFAULT_TIMEOUT, *, ssl_context=DEFAULT_SSL_CONTEXT, **kwargs):
 
+        self._ssl_context = ssl_context
         self._retry_count = retry_count
 
         self._session_config = kwargs
-        self._session_config[r'timeout'] = timeout if timeout is not None else DEFAULT_TIMEOUT
+        self._session_config[r'timeout'] = timeout
         self._session_config.setdefault(r'raise_for_status', True)
 
     def _encode_body(self, headers, data):
@@ -132,30 +158,6 @@ class _HTTPClient:
 
         return await response.read()
 
-    def _create_ssl_context(self):
-
-        global CACERT_FILE
-
-        return ssl.create_default_context(cafile=CACERT_FILE)
-
-    def create_timeout(
-            self, *, total=None, connect=None, sock_read=None, sock_connect=None
-    ) -> aiohttp.client.ClientTimeout:
-        """生成超时配置对象
-
-        Args:
-            total: 总超时时间
-            connect: 从连接池中等待获取连接的超时时间
-            sock_read: Socket数据接收的超时时间
-            sock_connect: Socket连接的超时时间
-
-        """
-
-        return aiohttp.client.ClientTimeout(
-            total=total, connect=connect,
-            sock_read=sock_read, sock_connect=sock_connect
-        )
-
     def create_form_data(self) -> aiohttp.FormData:
 
         return aiohttp.FormData()
@@ -397,7 +399,7 @@ class HTTPClientPool(HTTPClient):
 
     def __init__(self,
                  retry_count=5, use_dns_cache=True, ttl_dns_cache=10,
-                 limit=100, limit_per_host=0, timeout=None,
+                 limit=100, limit_per_host=0, timeout=DEFAULT_TIMEOUT,
                  **kwargs
                  ):
 
@@ -448,15 +450,9 @@ class Downloader(_HTTPClient):
     """HTTP文件下载器
     """
 
-    def __init__(self, file, retry_count=5, timeout=None, **kwargs):
+    def __init__(self, file, retry_count=5, timeout=DOWNLOAD_TIMEOUT, **kwargs):
 
-        global DOWNLOAD_TIMEOUT
-
-        super().__init__(
-            retry_count,
-            timeout if timeout is not None else DOWNLOAD_TIMEOUT,
-            **kwargs
-        )
+        super().__init__(retry_count, timeout, **kwargs)
 
         self._file = file
 
@@ -541,16 +537,9 @@ class DownloadBuffer(ContextManager, Downloader):
     """HTTP文件下载器(临时文件版)
     """
 
-    def __init__(self, timeout=None, **kwargs):
+    def __init__(self, timeout=DOWNLOAD_TIMEOUT, **kwargs):
 
-        global DOWNLOAD_TIMEOUT
-
-        super().__init__(
-            FileBuffer(),
-            1,
-            timeout if timeout is not None else DOWNLOAD_TIMEOUT,
-            **kwargs
-        )
+        super().__init__(FileBuffer(), 1, timeout, **kwargs)
 
     def _context_release(self):
 
