@@ -214,11 +214,11 @@ class RateLimiter:
 
         await asyncio.wait_for(self._waiting_tasks.put(task), self._timeout)
 
-        await self._fill_running_tasks()
+        self._fill_running_tasks()
 
         return task
 
-    async def _fill_running_tasks(self):
+    def _fill_running_tasks(self):
 
         loop_time = Utils.loop_time()
 
@@ -226,7 +226,7 @@ class RateLimiter:
 
             with catch_error():
 
-                task = await self._waiting_tasks.get()
+                task = self._waiting_tasks.get_nowait()
 
                 if (self._timeout <= 0) or ((loop_time - task.build_time) < self._timeout):
                     task.add_done_callback(self._done_callback)
@@ -240,4 +240,4 @@ class RateLimiter:
         if task in self._running_tasks:
             self._running_tasks.remove(task)
 
-        Utils.call_soon(self._fill_running_tasks)
+        self._fill_running_tasks()
