@@ -3,6 +3,7 @@
 __author__ = r'wsb310@gmail.com'
 
 import os
+import time
 import fastapi
 
 from starlette.types import ASGIApp, Receive, Scope, Send
@@ -19,11 +20,11 @@ from fastapi.openapi.docs import get_swagger_ui_html
 from ... import hagworm_label, hagworm_slogan
 from ... import __version__ as hagworm_version
 
+from ...extend.trace import get_trace_id, refresh_trace_id
 from ...extend.asyncio.base import Utils, install_uvloop
 from ...extend.logging import DEFAULT_LOG_FILE_NAME, DEFAULT_LOG_FILE_ROTATOR, init_logger
 
 from .response import Response, ErrorResponse
-from .middleware import RequestIDMiddleware
 
 
 get_swagger_ui_html.__kwdefaults__.update(
@@ -39,20 +40,22 @@ DEFAULT_HEADERS = [(r'Server', hagworm_label)]
 
 def create_fastapi(
         log_level=r'info', log_handler=None, log_file_path=None, log_file_name=DEFAULT_LOG_FILE_NAME,
-        log_file_rotation=DEFAULT_LOG_FILE_ROTATOR, log_file_retention=0xff,
+        log_file_rotation=DEFAULT_LOG_FILE_ROTATOR, log_file_retention=0xff, log_extra=None, log_enqueue=False,
         debug=False,
         routes=None,
         **setting
 ):
 
     init_logger(
-        log_level.upper(),
-        log_handler,
-        log_file_path,
-        log_file_name,
-        log_file_rotation,
-        log_file_retention,
-        debug
+        level=log_level.upper(),
+        handler=log_handler,
+        file_path=log_file_path,
+        file_name=log_file_name,
+        file_rotation=log_file_rotation,
+        file_retention=log_file_retention,
+        extra=log_extra,
+        enqueue=log_enqueue,
+        debug=debug
     )
 
     environment = Utils.environment()
@@ -72,8 +75,6 @@ def create_fastapi(
 
     _fastapi = fastapi.FastAPI(debug=debug, routes=routes, **setting)
 
-    _fastapi.add_middleware(RequestIDMiddleware)
-
     _fastapi.add_exception_handler(HTTPException, http_exception_handler)
     _fastapi.add_exception_handler(RequestValidationError, request_validation_exception_handler)
 
@@ -104,6 +105,10 @@ class APIRoute(fastapi.routing.APIRoute):
 
                 request = Request(scope, receive, send, self)
 
+                trace_id = refresh_trace_id(request.get_header(r'x-request-id', None))
+
+                request_time = time.time() * 1000
+
                 await self.prepare(request)
 
                 if is_coroutine:
@@ -111,6 +116,15 @@ class APIRoute(fastapi.routing.APIRoute):
                 else:
                     response = await run_in_threadpool(func, request)
 
+                response.headers.update(
+                    {
+                        r'x-trace-id': trace_id,
+                        r'x-request-time': r'{:.3f}'.format(request_time),
+                        r'x-request-consumed': r'{:.3f}'.format(time.time() * 1000 - request_time),
+                        r'x-request-payload': request.get_header(r'x-request-payload', r''),
+                    }
+                )
+
                 await response(scope, receive, send)
 
             except ErrorResponse as err:
@@ -181,18 +195,11 @@ class Request(fastapi.Request):
 
         self._api_route = api_route
 
-        self._request_id = RequestIDMiddleware.get_request_id()
-
-    @property
-    def request_id(self):
-
-        return self._request_id
-
     @property
     def debug_info(self):
 
         return {
-            'request_id': self._request_id,
+            'trace_id': get_trace_id(),
             'type': self.scope.get(r'type'),
             'http_version': self.scope.get(r'http_version'),
             'server': self.scope.get(r'server'),
